@@ -1,9 +1,9 @@
 package PAUSE::Packages;
-$PAUSE::Packages::VERSION = '0.13';
+$PAUSE::Packages::VERSION = '0.14';
 use 5.10.0;
 use autodie qw(open);
 
-use Moo;
+use Moo 1.004005;
 
 use CPAN::DistnameInfo;
 use Carp;
