@@ -1,7 +1,7 @@
 package PAUSE::Packages::Module;
-$PAUSE::Packages::Module::VERSION = '0.13';
+$PAUSE::Packages::Module::VERSION = '0.14';
 use 5.10.0;
-use Moo;
+use Moo 1.004005;
 
 has 'name'    => (is => 'ro');
 has 'version' => (is => 'ro');
