@@ -1,7 +1,7 @@
 package PAUSE::Packages::Release;
-$PAUSE::Packages::Release::VERSION = '0.13';
+$PAUSE::Packages::Release::VERSION = '0.14';
 use 5.10.0;
-use Moo;
+use Moo 1.004005;
 use CPAN::DistnameInfo;
 
 has 'modules' => (is => 'ro');
