@@ -1,7 +1,7 @@
 package PAUSE::Packages::ReleaseIterator;
-$PAUSE::Packages::ReleaseIterator::VERSION = '0.13';
+$PAUSE::Packages::ReleaseIterator::VERSION = '0.14';
 use 5.10.0;
-use Moo;
+use Moo 1.004005;
 use PAUSE::Packages;
 use PAUSE::Packages::Release;
 use PAUSE::Packages::Module;
